# Changelog

## [0.1.2](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/v0.1.1...v0.1.2) (2026-02-28)


### Bug Fixes

* resolve publish pipeline configuration bugs across sdks ([13d521f](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/13d521faf52138f4c00c8bc86c123fa269a65d1c))

## [0.1.1](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/v0.1.0...v0.1.1) (2026-02-28)


### Bug Fixes

* remove npm registry-url config to fix OIDC provenance and bump all SDKs ([5f93206](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/5f932067c98113dca6941d8ffbe2371834007335))
